#
# spec file for package sblim-cmpi-fsvol
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sblim-cmpi-fsvol
BuildRequires:  gcc-c++
BuildRequires:  sblim-cmpi-base-devel
BuildRequires:  sblim-cmpi-devel
BuildRequires:  sblim-indication_helper-devel
BuildRequires:  sblim-sfcb
BuildRequires:  sblim-testsuite
Version:        1.5.1
Release:        3.3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       cim-server
Requires:       sblim-cmpi-base
Url:            http://sblim.wiki.sourceforge.net/
Source:         http://prdownloads.sourceforge.net/sblim/%{name}-%{version}.tar.bz2
Summary:        SBLIM File System & Volume Mgmt. Instrumentation for CMPI
License:        EPL-1.0
Group:          System/Management
#!BuildIgnore:  tog-pegasus

%description
The Filesystem & Volume Management Instrumentation allows you to get
information about mounted ( /etc/mtab ) and unmounted ( /etc/fstab )
filesystems via CIMOM technology/infrastructure.

Authors:
--------
    SBLIM Project

%package devel
Summary:        SBLIM File System & Volume Mgmt. Instrumentation Header Development Files
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
SBLIM File System & Volume Mgmt. Provider Development Package

Authors:
--------
    SBLIM Project

%package testsuite
Summary:        SBLIM File System & Volume Mgmt. Instrumentation (test suite)
Group:          System/Management
Requires:       %{name} = %{version}
Requires:       sblim-testsuite

%description testsuite
Test suite for the Standards Based Linux Instrumentation File System & Volume Mgmt. Providers

Authors:
--------
    SBLIM Project


%prep
%setup -n %{name}-%{version}

%build
%configure TESTSUITEDIR=%{_datadir}/sblim-testsuite --disable-static
%{__make}

%install
%if 0%{?suse_version}
%makeinstall docdir=%{_docdir}/%{name}
%else
make install DESTDIR=%{buildroot} docdir=%{_docdir}/%{name}-%{version}
%endif
#rm %buildroot%_libdir/cmpi/*.la
#rm %buildroot%_libdir/*.la

%clean
%{__rm} -rf %{buildroot}
%define PEGASUS_MOF CIM_UnixLocalFileSystem,CIM_NFS,CIM_HostedFileSystem,CIM_BootOSFromFS

%pre
if [ "$1" -gt 1 ]; then
  d=%{_datadir}/%{name}
  $d/provider-register.sh -d -r $d/*.registration -m $d/*.mof
fi

%post
# compile MOF
/sbin/ldconfig
# Register Schema and Provider - this is higly provider specific  
# tog-pegasus needs some schemes registered first  
if [ -x /usr/bin/peg-loadmof.sh ]; then  
    peg-loadmof.sh -n root/cimv2 /usr/share/mof/cim-current/*/{%{PEGASUS_MOF}}.mof  
    rctog-pegasus try-restart  
fi  
# and then following script can handle registration for various providers  
d=%{_datadir}/%{name}
$d/provider-register.sh -r $d/*.registration -m $d/*.mof

%preun
if [ "$1" = "0" ]; then
  d=%{_datadir}/%{name}
  $d/provider-register.sh -d -r $d/*.registration -m $d/*.mof
fi

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root) 
%{_libdir}/cmpi/*.so
%{_libdir}/cmpi/*.la
%{_libdir}/*.la
%{_libdir}/*.so.*
%if 0%{?suse_version}
%doc %{_docdir}/%{name}
%else
%doc %{_docdir}/%{name}-%{version}
%endif
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/

%files devel
%defattr(-,root,root) 
%{_libdir}/*.so
%{_includedir}/sblim/*.h

%files testsuite
%defattr(-,root,root)
%dir %{_datadir}/sblim-testsuite
%{_datadir}/sblim-testsuite/*

%changelog
* Thu Apr 10 2014 kkaempf@suse.com
- Upgrade to 1.5.1
  Bugs fixed:
  - 3044649 remove Linux_CSProcessor from reg file
  - 3275200 provider scripts don't pass all command line opts
  - 3275169 bash error reported in provider bootstrap scripts
  - 3303682 include virtio devices in disk query
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Mon Sep 13 2010 kkaempf@novell.com
- Fix RHEL build
* Sat Jan 16 2010 kkaempf@novell.com
- split off -devel and -testsuite packages
* Mon Jun  8 2009 mhrusecky@suse.cz
- fixed registration with tog-pegasus
- updated to version 1.5.0
  * Eclipse Public Licence
* Tue Jan 13 2009 npaxton@novell.com
- Add a check for provider-register.sh in case upgrading from an
  old version of rpm that may have removed it without check for
  upgrade/uninstall/etc
* Fri Dec 12 2008 bwhiteley@suse.de
- Added .la files back.  Added back PreReq for loadmof.sh
  and rmmof.sh.
* Fri Dec 12 2008 bwhiteley@suse.de
- Made use of provider-register.sh conditional on presence of sfcb,
  and added back calls to loadmof.sh/rmmof.sh so the package works
  for both sfcb and openwbem.
* Mon Aug 25 2008 npaxton@novell.com
- Switch from provider-register.sh from sblim-cmpi-base to
  locally-provided provider-register.sh
* Wed Jul  9 2008 npaxton@novell.com
- Added BuildRequires dependency on sblim-sfcb so can control the
  cimom used for testing install of resulting rpm's
* Wed Jul  9 2008 npaxton@novell.com
- switch from loadmof.sh to provider-register.sh to add support for
  sfcb cimom
- minor spec file changes to bring sles10-sp2 and stable in sync
* Thu Nov  1 2007 mmarek@suse.cz
- updated to 1.4.4
  fixed upstream bugs:
  - 1597688 Fixed data gathering that caused seg faults
  - 1601706 Fixed unresolved symbols in shared lib
- removed static libs
* Wed Mar 15 2006 mrueckert@suse.de
- update to version 1.4.3  (#142308)
  (fixing the following upstream bugs)
  o Bugs 1199129, 1203849: Updates for warning-free compilation
    with CMPI headers >= 1.0.0.
  o Bugs 1353262: Better support for Fedora/RH RPM environment.
  o Bugs 1328734: Fixed range for kb_read and kb_transfered
  o Bugs 1285011: 1285324: Fixed portability issues.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov  2 2005 mrueckert@suse.de
- update to 1.4.2
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Wed May 12 2004 nashif@suse.de
- Do not De-register when updating package
* Mon May 10 2004 nashif@suse.de
- De-register providers when package is uninstalled (#39667)
* Tue May  4 2004 nashif@suse.de
- Remove binaries from tar archive (#39844)
* Fri Apr 30 2004 nashif@suse.de
- Update to 1.2.5
* Wed Apr 14 2004 nashif@suse.de
- Added PreReq for loadmof.sh
* Wed Apr  7 2004 nashif@suse.de
- Initial Release
